@@ -2,10 +2,10 @@
 
 pub mod aa_tree;
 pub mod abstract_structs;
-pub mod abstract_traits;
 pub mod argsort;
 pub mod binary_search;
 pub mod bitwise;
+pub mod chinese_remainder_theorem;
 pub mod cmp;
 pub mod combinatorics;
 pub mod division;
@@ -17,6 +17,7 @@ pub mod graph_pointer_directed;
 pub mod graph_pointer_mixed;
 pub mod graph_pointer_undirected;
 pub mod graph_trait_pointer_mixed;
+pub mod group_theory;
 pub mod longest_common_prefix;
 pub mod modular_static;
 pub mod power;
