@@ -1,12 +1,10 @@
-use crate::abstract_traits;
+use crate::group_theory;
 
-pub trait Power<S = Self, T = abstract_traits::Multiplicative>:
-    abstract_traits::Monoid<S, T>
-{
+pub trait Power<S = Self, T = group_theory::Multiplicative>: group_theory::Monoid<S, T> {
     fn pow(value: &S, expontent: usize) -> S;
 }
 
-impl<S, T, M: abstract_traits::Monoid<S, T>> Power<S, T> for M {
+impl<S, T, M: group_theory::Monoid<S, T>> Power<S, T> for M {
     fn pow(value: &S, exponent: usize) -> S {
         if exponent == 0 {
             return M::identity();
